@@ -9,21 +9,27 @@ library("JointAI")
 
 ## ---- echo = F------------------------------------------------------------------------------------
 tab <- rbind(
-c("`analysis_main`", "`betas` and `sigma_y` (and `D` in mixed models)"),
-c("`analysis_random`", "`ranef`, `D`, `invD`, `RinvD`"),
-c('`imp_pars`', '`alphas`, `tau_imp`, `gamma_imp`, `delta_imp`'),
+c("`analysis_main`", "`betas` and `sigma_main`, `tau_main` (in beta regression) or `shape_main` (in parametric survival models), `D_main` (in multi-level models) and `basehaz` (in proportional hazards models)"),
+c("`analysis_random`", "`ranef_main`, `D_main`, `invD_main`, `RinvD_main`"),
+c('`other_models`', '`alphas`, `tau_other`, `gamma_other`, `delta_other`'),
 c('`imps`', 'imputed values'),
-c('`betas`', 'regression coefficients of the analysis model'),
-c('`tau_y`', 'precision of the residuals from the analysis model'),
-c('`sigma_y`', 'standard deviation of the residuals from the analysis model'),
-c('`ranef`', 'random effects'),
-c('`D`', 'covariance matrix of the random effects'),
-c('`invD`', 'inverse of `D`'),
-c('`RinvD`', 'scale matrix in Wishart prior for `invD`'),
-c('`alphas`', 'regression coefficients in the imputation models'),
-c('`tau_imp`', 'precision parameters of the residuals from imputation models'),
-c('`gamma_imp`', 'intercepts in ordinal imputation models'),
-c('`delta_imp`', 'increments of ordinal intercepts'),
+c('`betas`', 'regression coefficients of the main analysis model(s)'),
+c('`tau_main`', 'precision of the residuals from the analysis model(s)'),
+c('`sigma_main`', 'standard deviation of the residuals from the analysis model(s)'),
+c('`gamma_main`', 'intercepts in ordinal main model'),
+c('`delta_main`', 'increments of ordinal intercepts in main model(s)'),
+c('`ranef_main`', 'random effects of the analysis model(s)'),
+c('`D_main`', 'covariance matrix of the random effects of the main model(s)'),
+c('`invD_main`', 'inverse of `D_main`'),
+c('`RinvD_main`', 'scale matrix in Wishart prior for `invD_main`'),
+c('`alphas`', 'regression coefficients in the covariate models'),
+c('`tau_other`', 'precision parameters of the residuals from covariate models'),
+c('`gamma_other`', 'intercepts in ordinal covariate models'),
+c('`delta_other`', 'increments of ordinal intercepts in covariate models'),
+c('`ranef_other`', 'random effects of the covariate model(s)'),
+c('`D_other`', 'covariance matrix of the random effects of the covariate model(s)'),
+c('`invD_other`', 'inverse of `D_other`'),
+c('`RinvD_other`', 'scale matrix in Wishart prior for `invD_other`'),
 c('`other`', 'additional parameters')
 )
 colnames(tab) = c('name/key word', 'what is monitored')
@@ -31,11 +37,11 @@ colnames(tab) = c('name/key word', 'what is monitored')
 knitr::kable(tab)
 
 ## ----lm1_1, message = FALSE-----------------------------------------------------------------------
-lm1 <- lm_imp(SBP ~ gender + WC + alc + creat, data = NHANES,  n.adpat = 0)
+lm1 <- lm_imp(SBP ~ gender + WC + alc + creat, data = NHANES,  n.adapt = 0)
 
 parameters(lm1)
 
-## ----lm2_1, message = FALSE-----------------------------------------------------------------------
+## ----lm2_1, message = FALSE, warning = FALSE------------------------------------------------------
 lm2 <- lm_imp(SBP ~ age + WC + alc + smoke + occup,
               data = NHANES, n.adapt = 0,
               monitor_params = c(imps = TRUE, analysis_main = FALSE)
@@ -43,9 +49,12 @@ lm2 <- lm_imp(SBP ~ age + WC + alc + smoke + occup,
 
 parameters(lm2)
 
-## ----lm3_1, message = FALSE-----------------------------------------------------------------------
+## -------------------------------------------------------------------------------------------------
+head(lm2$data_list$M_lvlone)
+
+## ----lm3_1, message = FALSE, warning=FALSE--------------------------------------------------------
 lm3 <- lm_imp(SBP ~ age + WC + alc + smoke + occup, data = NHANES, n.adapt = 0,
-              monitor_params = c(imp_pars = TRUE, analysis_main = FALSE)
+              monitor_params = c(other_models = TRUE, analysis_main = FALSE)
 )
 
 parameters(lm3)
@@ -73,20 +82,20 @@ colnames(tab) <- c('argument', 'explanation')
 
 knitr::kable(tab, row.names = FALSE)
 
-## ---- message = FALSE-----------------------------------------------------------------------------
+## ---- message = FALSE, warning=FALSE--------------------------------------------------------------
 lme1 <- lme_imp(bmi ~ age + EDUC, random = ~age | ID, data = simLong, n.adapt = 0)
 
 parameters(lme1)
 
-## ---- message = FALSE-----------------------------------------------------------------------------
+## ---- message = FALSE, warning=FALSE--------------------------------------------------------------
 lme2 <- lme_imp(bmi ~ age + EDUC, random = ~age | ID, data = simLong, n.adapt = 0,
                 monitor_params = c(analysis_random = TRUE))
 
 parameters(lme2)
 
-## ---- message = FALSE-----------------------------------------------------------------------------
+## ---- message = FALSE, warning = FALSE------------------------------------------------------------
 lme3a <- lme_imp(bmi ~ age + EDUC, random = ~age | ID, data = simLong, n.adapt = 0,
-                 monitor_params = c(analysis_main = TRUE, RinvD = TRUE))
+                 monitor_params = c(analysis_main = TRUE, RinvD_main = TRUE))
 
 parameters(lme3a)
 
@@ -94,8 +103,8 @@ parameters(lme3a)
 lme3b <- lme_imp(bmi ~ age + EDUC, random = ~age | ID, data = simLong, n.adapt = 0,
                 monitor_params = c(analysis_main = TRUE,
                                    analysis_random = TRUE,
-                                   RinvD = FALSE,
-                                   ranef = FALSE))
+                                   RinvD_main = FALSE,
+                                   ranef_main = FALSE))
 
 parameters(lme3b)
 
@@ -109,7 +118,7 @@ parameters(lm4)
 ## ---- fig.width = 7, fig.height = 6, warning = FALSE----------------------------------------------
 # Run a model monitoring analysis parameters and imputation parameters
 lm5 <- lm_imp(SBP ~ gender + WC + alc + creat, data = NHANES, n.iter = 100,
-              progress.bar = 'none', monitor_params = c(imp_pars = TRUE))
+              progress.bar = 'none', monitor_params = c(other_models = TRUE))
 
 # model summary
 summary(lm5)
@@ -126,7 +135,7 @@ GR_crit(lm5)
 # Monte Carlo Error of the MCMC sample
 MC_error(lm5)
 
-## ---- fig.height = 1.5, message = FALSE-----------------------------------------------------------
+## ---- fig.height = 1.5, message = FALSE, out.width = "100%"---------------------------------------
 # Re-run the model from above, now creating MCMC samples
 lm4 <- lm_imp(SBP ~ gender + WC + alc + creat,
               data = NHANES, n.iter = 100, progress.bar = 'none',
@@ -137,34 +146,34 @@ traceplot(lm4, ncol = 4)
 
 ## ----GRcrit_lm5-----------------------------------------------------------------------------------
 # we use lm5 from above
-GR_crit(lm5, subset = c(analysis_main = FALSE, imp_pars = TRUE))
+GR_crit(lm5, subset = c(analysis_main = FALSE, other_models = TRUE))
 
 ## ----trace_lm5, fig.width = 5, fig.height = 2, out.width = "60%"----------------------------------
 summary(lm5, subset = list(other = c('creat', 'alc>=1')))
 
-## ----lm2_2, fig.height = 2, fig.width = 5, out.width = "60%", message = FALSE---------------------
+## ----lm2_2, fig.height = 2, fig.width = 5, out.width = "50%", warning = FALSE---------------------
 # Re-run the model from above, now creating MCMC samples
 lm2 <- lm_imp(SBP ~ age + WC + alc + smoke + occup,
               data = NHANES, n.iter = 100, progress.bar = 'none',
               monitor_params = c(imps = TRUE, analysis_main = FALSE)
 )
 
-# select only imputed values for 'WC' (3rd column of Xc)
-sub3 <- grep('Xc\\[[[:digit:]]+,3\\]', parameters(lm2), value = TRUE)
+# select only imputed values for 'WC' (4th column of Wc)
+sub3 <- grep('M_lvlone\\[[[:digit:]]+,5\\]', parameters(lm2)$coef, value = TRUE)
 sub3
 
 traceplot(lm2, subset = list(other = sub3), ncol = 2)
 
-## ---- fig.height = 4, message = FALSE-------------------------------------------------------------
+## ---- fig.height = 4, message = FALSE, warning = FALSE--------------------------------------------
 lme4 <- lme_imp(bmi ~ age + EDUC, random = ~age | ID,
                 data = simLong, n.iter = 100, progress.bar = 'none',
-                monitor_params = c(analysis_main = FALSE, ranef = TRUE))
+                monitor_params = c(analysis_main = FALSE, ranef_main = TRUE))
 
 # exract random intercepts
-ri <- grep('^b\\[[[:digit:]]+,1\\]$', colnames(lme4$MCMC[[1]]), value = T)
+ri <- grep('^b_bmi_ID\\[[[:digit:]]+,1\\]$', colnames(lme4$MCMC[[1]]), value = T)
 
 # extract random slopes
-rs <- grep('^b\\[[[:digit:]]+,2\\]$', colnames(lme4$MCMC[[1]]), value = T)
+rs <- grep('^b_bmi_ID\\[[[:digit:]]+,2\\]$', colnames(lme4$MCMC[[1]]), value = T)
 
 # plot the chains of 8 randomly selected random intercepts
 traceplot(lme4, subset = list(other = sample(ri, size = 8)), ncol = 4)
