@@ -224,7 +224,8 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
                       no_model = "time", data = longDF,
                       n.iter = 10, n.adapt = 5, seed = 2020,
                       warn = FALSE, mess = FALSE),
-        m8b = lme_imp(y ~ c1 + c2 + time, random = ~ time + c2|id, data = longDF,
+        m8b = lme_imp(y ~ c1 + c2 + time, random = ~ time + c2|id,
+                      data = longDF,
                       n.iter = 10, n.adapt = 5, seed = 2020,
                       warn = FALSE, mess = FALSE),
         m8c = lme_imp(y ~ B2 * c1 + c2 + time, random = ~ time + c1|id,
